@@ -18,6 +18,7 @@ import pickle, random
 import threading
 import sys, os, re
 from os import path
+import glob
 import traceback
 from traceback import print_exc
 from calculate.lib.cl_log import log
@@ -77,6 +78,15 @@ class CommonMethods:
 
             origdata = readFile(orig)
             newdata = readFile(data[CFGFNAME])
+            pattern = "%s/._cfg????_%s"%(os.path.dirname(orig),
+                                         os.path.basename(orig))
+            for fn in glob.glob(pattern):
+                try:
+                    if fn == data[CFGFNAME]:
+                        continue
+                    os.unlink(fn)
+                except:
+                    pass
             if (self.clVars.Get('cl_autoupdate_set') == 'on' or 
                 origdata == newdata):
                 answ = "use new"
